<?php
/**
 *
 *
 *  
 * @subpackage heavy
 */

include get_template_directory() . '/settings.php';

function heavy_setup() {
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on heavy, use a find and replace
	 * to change 'heavy' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'heavy', get_template_directory() . '/languages' );
	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	require_once get_template_directory() . "/heavy-recent-comments.php";
	if ( is_readable( $locale_file ) )
		require_once $locale_file;

	// Set the content width based on the theme's design and stylesheet.
	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
			'primary' => __( 'Primary Menu', 'heavy' ),
		) );
	//Add editor style
	add_editor_style( '' );

	//Edit Header Image
	define( 'HEADER_TEXTCOLOR', 'ffffff' );
	define( 'HEADER_IMAGE', get_template_directory_uri() .'/images/bgf.jpg' ); // %s is the template dir uri
	define( 'HEADER_IMAGE_WIDTH', 1000 ); // use width and height appropriate for your theme
	define( 'HEADER_IMAGE_HEIGHT', 273 );
}

add_action( 'after_setup_theme', 'heavy_setup' );

//  Add default posts and comments RSS feed links to head
add_theme_support( 'automatic-feed-links' );

// Add support for the Aside and Gallery Post Formats
add_theme_support( 'post-formats', array( 'aside', 'gallery' ) );


// Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
function heavy_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'heavy_page_menu_args' );

// Enable support for post-thumbnails
add_theme_support( 'post-thumbnails' );
if ( function_exists( 'add_theme_support' ) ) {
	add_theme_support( 'post-thumbnails' );
}

//Include One Theme Settings stylesheet
function heavy_stylesheet() {
	wp_register_style( 'heavy-admin-options', get_template_directory_uri() . '/options.css' );
	wp_enqueue_style( 'heavy-admin-options' );
}
add_action( 'admin_enqueue_scripts', 'heavy_stylesheet' );
//include theme script

function heavy_include_scripts() {
	wp_deregister_script( 'jquery' );
	wp_register_script( 'jquery', 'http://code.jquery.com/jquery-1.8.2.min.js' );
	wp_enqueue_script( 'jquery' );
	wp_register_script( 'scrollbar_script', get_template_directory_uri() . '/js/jquery.nicescroll.js', 'jquery' );
	wp_enqueue_script( 'scrollbar_script' );
	wp_register_script( 'height_script', get_template_directory_uri() . '/js/height.js', 'jquery' );
	wp_enqueue_script( 'height_script' );
	wp_register_script( 'html_script', get_template_directory_uri() . '/js/html5.js' );
	if ( is_singular() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );}
	wp_enqueue_script( 'html_script' );
}

add_action( 'wp_enqueue_scripts', 'heavy_include_scripts' ); // For use on the Front end (ie. Theme)

//Register widgetized area and update sidebar with default widgets
function heavy_widgets_init() {
	register_sidebar( array (
			'name' => __( 'Links', 'heavy' ),
			'id' => 'sidebar-1',
			'description' => __( 'Insert "Links" widget', 'heavy' ),
			'before_widget' => '',
			'after_widget' => "",
			'before_title' => '<h1 class="widget-title">',
			'after_title' => '</h1>',
		) );
	register_sidebar( array (
			'name' => __( 'Description', 'heavy' ),
			'id' => 'sidebar-2',
			'description' => __( 'Insert widget or banner', 'heavy' ),
			'before_widget' => '<div>',
			'after_widget' => "</div>",
			'before_title' => '<h1 class="widget-title">',
			'after_title' => '</h1>',
		) );
	register_sidebar( array (
			'name' => __( 'Sidebar', 'heavy' ),
			'id' => 'sidebar-3',
			'description' => __( 'Any text', 'heavy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => "</aside>",
			'before_title' => '<h1 class="widget-title">',
			'after_title' => '</h1>',
		) );
	register_sidebar( array (
			'name' => __( 'Header Sidebar', 'heavy' ),
			'id' => 'sidebar-4',
			'description' => __( 'First "Text" widget recomended', 'heavy' ),
			'before_widget' => '<div class="widget_body2">',
			'after_widget' => "</div>",
			'before_title' => '<h1 class="widget-title">',
			'after_title' => '</h1>',
		) );
	register_sidebar( array (
			'name' => __( 'Footer About', 'heavy' ),
			'id' => 'sidebar-5',
			'description' => __( 'Any text', 'heavy' ),
			'before_widget' => '<div class="About">',
			'after_widget' => "</div>",
			'before_title' => '<h1 class="widget-title">',
			'after_title' => '</h1>',
		) );

}
add_action( 'widgets_init', 'heavy_widgets_init' );

function heavy_posts() {
	$sidebar_options = get_option( 'heavy_theme_sidebar_options' );
	if ( isset($sidebar_options['post_number']) && $sidebar_options['post_number'] != '' && $sidebar_options['post_number'] != 0) {$post_number = $sidebar_options['post_number']-1;}
	else {$post_number = 4;}

	if (!isset($sidebar_options['resent_post']) || $sidebar_options['resent_post'] != 1 ) {
		echo '<h1 class="widget-title" id="recent-post">'.__( 'Recent Posts' ).'</h1><li id="meta" class="widget-container">';
		$the_query = new WP_Query( 'showposts='.$post_number.'&orderby=post_date&order=desc' );
		while ( $the_query->have_posts() ) : $the_query->the_post();
		echo '<div class="latest-post">';
		the_post_thumbnail( array( 45, 45 ), array ( 'class' => 'alignleft' ) );
		echo '<a title="';
		the_title();
		echo'" href="';
		the_permalink();
		echo'" rel="bookmark">';
		the_title();
		echo'<br /><div class="date">';
		the_time( 'F j, Y' );
		echo '<br /><span id="comment-number">';
		comments_number( 'No Comments', 'One Comment', '% Comments' );
		echo '</span></div></a><div class="clear"></div></div>';
		endwhile;
		wp_reset_query();
		echo'</li>';
	}
}

//Add comment
function heavy_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
	case '' :
?>

<div <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
				<footer>
						<div class="comment-author vcard"> <?php echo get_avatar( $comment, 40 ); ?> <?php printf( __( '%s <span class="says">says:</span>', 'heavy' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?> </div>
						<!-- .comment-author .vcard -->
						<?php if ( $comment->comment_approved == '0' ) : ?>
						<em>
						<?php _e( 'Your comment is awaiting moderation.', 'heavy' ); ?>
						</em> <br />
						<?php endif; ?>
						<div class="comment-meta commentmetadata"> <a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
								<time pubdate datetime="<?php comment_time( 'c' ); ?>">
										<?php
	/* translators: 1: date, 2: time */
	printf( __( '%1$s at %2$s', 'heavy' ), get_comment_date(),  get_comment_time() ); ?>
								</time>
								</a>
								<?php edit_comment_link( __( '(Edit)', 'heavy' ), ' ' );
?>
						</div>
						<!-- .comment-meta .commentmetadata -->
				</footer>
				<div class="comment-content">
						<?php comment_text(); ?>
				</div>
				<div class="reply">
						<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div>
				<!-- .reply -->
		</article>
		<!-- #comment-##  -->
</div>
<?php
	break;
case 'pingback'  :
case 'trackback' :
?>
<li class="post pingback">
		<p>
				<?php _e( 'Pingback:', 'heavy' ); ?>
				<?php comment_author_link(); ?>
				<?php edit_comment_link( __( '(Edit)', 'heavy' ), ' ' ); ?>
		</p>
		<?php
	break;
	endswitch;
}

//Search Form
function heavy_search_form( $form ) {
	$form = '<form role="search" method="get" id="searchform" action="' . home_url( '/' ) . '" >
    <div>
    <input type="text" value="' . get_search_query() . '" name="s" id="s"  placeholder="Search"/>
    <input type="submit" id="searchsubmit" value="'. esc_attr__( '      ' ) .'" />
    </div>
    </form>';
	return $form;
}
add_filter( 'get_search_form', 'heavy_search_form' );

// gets included in the site header
function heavy_header_style() {
?>
<style type="text/css">
        #widget_body {
            background: url(<?php header_image(); ?>);
        }
    </style>
<?php
}

// gets included in the admin header
function heavy_admin_header_style() {
?>
<style type="text/css">
        #heading {
            width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
            height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
            background: no-repeat;
        }
</style>
<?php
}

	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );

if ( ! function_exists( 'heavy_content_nav' ) ):
/**
 * Display navigation to next/previous pages when applicable
 *
 */
function heavy_content_nav( $nav_id ) {
	global $wp_query;

	?>
	<nav id="<?php echo $nav_id; ?>">
		<h1 class="assistive-text section-heading"><?php _e( 'Post navigation', 'toolbox' ); ?></h1>

	<?php if ( is_single() ) : // navigation links for single posts ?>

		<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'toolbox' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'toolbox' ) . '</span>' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'toolbox' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'toolbox' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav><!-- #<?php echo $nav_id; ?> -->
	<?php
}
endif; // heavy_content_nav

?>
