<?php

/**
 * This function introduces the theme options into the 'Appearance' menu and into a top-level 
 * 'heavy Theme' menu.
 */
function heavy_example_theme_menu() {

	add_theme_page(
		'Heavy Theme Options', 			// The title to be displayed in the browser window for this page.
		'Heavy Theme Options',			// The text to be displayed for this menu item
		'administrator',				// Which type of users can see this menu item
		'heavy_theme_options',			// The unique ID - that is, the slug - for this menu item
		'heavy_theme_display'			// The name of the function to call when rendering this menu's page
	);

} // end heavy_example_theme_menu
add_action( 'admin_menu', 'heavy_example_theme_menu' );

/**
 * Renders a simple page to display for the theme menu defined above.
 */
function heavy_theme_display( $active_tab = 'header_options' ) {
?>
	<!-- Create a header in the default WordPress 'wrap' container -->
	<div class="wrap">
	
		<div id="icon-themes" class="icon32"></div>
		<h2>Heavy Theme Options</h2>
		<?php settings_errors(); ?>
		
		<?php if( isset( $_GET[ 'tab' ] ) ) {
			$active_tab = $_GET[ 'tab' ];
		} else if( $active_tab == 'sidebar_options' ) {
			$active_tab = 'sidebar_options';
		} else if( $active_tab == 'header_options' ) {
			$active_tab = 'header_options';
		} // end if/else ?>

		<h2 class="nav-tab-wrapper">
            <a href="?page=heavy_theme_options&tab=header_options" class="nav-tab <?php echo $active_tab == 'header_options' ? 'nav-tab-active' : ''; ?>">Header Settings</a>
            <a href="?page=heavy_theme_options&tab=sidebar_options" class="nav-tab <?php echo $active_tab == 'sidebar_options' ? 'nav-tab-active' : ''; ?>">Sidebar Settings</a>
		</h2>

		<form method="post" action="options.php">
            <div class="heavy_wrap">
			<?php

				if( $active_tab == 'sidebar_options' ) {

					settings_fields( 'heavy_theme_sidebar_options' );
					do_settings_sections( 'heavy_theme_sidebar_options' );

				} else {

					settings_fields( 'heavy_theme_header_options' );
					do_settings_sections( 'heavy_theme_header_options' );

				} // end if/else

				submit_button();
			?>
            </div>
		</form>
		
	</div><!-- /.wrap -->
<?php
} // end heavy_theme_display

/* ------------------------------------------------------------------------ *
 * Setting Registration
 * ------------------------------------------------------------------------ */ 

/**
 * Initializes the theme's social options by registering the Sections,
 * Fields, and Settings.
 *
 * This function is registered with the 'admin_init' hook.
 */ 
function heavy_theme_intialize_sidebar_options() {

	if( false == get_option( 'heavy_theme_sidebar_options' ) ) {	
		add_option( 'heavy_theme_sidebar_options' );
	} // end if

	add_settings_section(
		'sidebar_settings_section',			// ID used to identify this section and with which to register options
		'',					                // Title to be displayed on the administration page
		'heavy_sidebar_options_callback',	// Callback used to render the description of the section
		'heavy_theme_sidebar_options'		// Page on which to add this section of options
	);

	add_settings_field(	
		'post_number',						
		'Select number of posts',							
		'heavy_post_number_callback',	
		'heavy_theme_sidebar_options',	
		'sidebar_settings_section'			
	);
    
    add_settings_field(
		'resent_post',
		'Disable Recent Posts',
		'heavy_resent_post_element_callback',
		'heavy_theme_sidebar_options',
		'sidebar_settings_section'
	);
    
    add_settings_field(	
		'comments_number',						
		'Select number comments',							
		'heavy_comments_number_callback',	
		'heavy_theme_sidebar_options',	
		'sidebar_settings_section'			
	);
    
    add_settings_field(
		'resent_comments',
		'Disable Recent Comments',
		'heavy_resent_comments_element_callback',
		'heavy_theme_sidebar_options',
		'sidebar_settings_section'
	);

	register_setting(
		'heavy_theme_sidebar_options',
		'heavy_theme_sidebar_options',
		'heavy_theme_sanitize_sidebar_options'
	);

} // end heavy_theme_intialize_sidebar_options
add_action( 'admin_init', 'heavy_theme_intialize_sidebar_options' );

/**
 * Initializes the theme's input example by registering the Sections,
 * Fields, and Settings. This particular group of options is used to demonstration
 * validation and sanitization.
 *
 * This function is registered with the 'admin_init' hook.
 */ 
function heavy_theme_initialize_header_options() {

	if( false == get_option( 'heavy_theme_header_options' ) ) {	
		add_option( 'heavy_theme_header_options' );
	} // end if

	add_settings_section(
		'header_options_section',
		'',
		'heavy_header_options_callback',
		'heavy_theme_header_options'
	);

	add_settings_field(	
		'header_title',						
		'Header Title',							
		'heavy_input_header_callback',	
		'heavy_theme_header_options',	
		'header_options_section'			
	);

	add_settings_field(	
		'header_textarea',						
		'TextArea',							
		'heavy_textarea_element_callback',	
		'heavy_theme_header_options',	
		'header_options_section'			
	);

	add_settings_field(
		'header_checkbox',
		'Disable Additional textbox',
		'heavy_checkbox_element_callback',
		'heavy_theme_header_options',
		'header_options_section'
	);

	register_setting(
		'heavy_theme_header_options',
		'heavy_theme_header_options',
		'heavy_theme_validate_header_options'
	);

} // end heavy_theme_initialize_header_options
add_action( 'admin_init', 'heavy_theme_initialize_header_options' );

/* ------------------------------------------------------------------------ *
 * Section Callbacks
 * ------------------------------------------------------------------------ */ 
 
/**
 * This function provides a simple description for the Social Options page. 
 *
 * It's called from the 'heavy_theme_intialize_sidebar_options' function by being passed as a parameter
 * in the add_settings_section function.
 */
function heavy_sidebar_options_callback() {
} // end heavy_general_options_callback

/**
 * This function provides a simple description for the Input Examples page.
 *
 * It's called from the 'heavy_theme_intialize_header_options_options' function by being passed as a parameter
 * in the add_settings_section function.
 */
function heavy_header_options_callback() {
} // end heavy_general_options_callback

/* ------------------------------------------------------------------------ *
 * Field Callbacks
 * ------------------------------------------------------------------------ */ 

/**
 * This function renders the interface elements for toggling the visibility of the header element.
 * 
 * It accepts an array or arguments and expects the first element in the array to be the description
 * to be displayed next to the checkbox.
 */

function heavy_post_number_callback() {

	$options = get_option( 'heavy_theme_sidebar_options' );

	// Render the output
    echo '<div class="heavy_opts">';
	echo '<input type="text" id="post_number" name="heavy_theme_sidebar_options[post_number]" value="' . $options['post_number'] . '" />';
    echo '</div>';
} // end heavy_post_number_callback 

function heavy_resent_post_element_callback() {

	$options = get_option( 'heavy_theme_sidebar_options' );
	if (isset($options['resent_post'])){
	$isset_post = $options['resent_post'];
	} else { $isset_post = 0;}
	$html = '<input type="checkbox" id="resent_post" name="heavy_theme_sidebar_options[resent_post]" value="1"' . checked( 1, $isset_post, false ) . '/>';
	echo '<div class="heavy_opts">';
    echo $html;
    echo '</div>';

} // end heavy_resent_post_element_callback

function heavy_comments_number_callback() {

	$options = get_option( 'heavy_theme_sidebar_options' );

	// Render the output
    echo '<div class="heavy_opts">';
	echo '<input type="text" id="comments_number" name="heavy_theme_sidebar_options[comments_number]" value="' . $options['comments_number'] . '" />';
    echo '</div>';
} // end heavy_comments_number_callback 
 

function heavy_resent_comments_element_callback() {

	$options = get_option( 'heavy_theme_sidebar_options' );
	if (isset($options['resent_comments'])){
	$isset_comments = $options['resent_comments'];
	} else { $isset_comments = 0;}
	
	$html = '<input type="checkbox" id="resent_comments" name="heavy_theme_sidebar_options[resent_comments]" value="1"' . checked( 1, $isset_comments, false ) . '/>';
	echo '<div class="heavy_opts">';
    echo $html;
    echo '</div>';
} // end heavy_resent_comments_element_callback

// Header fields 
 
function heavy_input_header_callback() {

	$options = get_option( 'heavy_theme_header_options' );

	// Render the output
	echo '<div class="heavy_opts">';
    echo '<small>'._e('Enter a title to display for your header.','heavy').'</small><br />';
    echo '<input type="text" id="heavy_header" name="heavy_theme_header_options[heavy_header]" value="' . $options['heavy_header'] . '" />';
    echo '</div>';
} // end heavy_input_header_callback

function heavy_textarea_element_callback() {

	$options = get_option( 'heavy_theme_header_options' );

	// Render the output
    echo '<div class="heavy_opts">';
    echo '<small>'._e('Insert there text.','heavy').'</small><br />';
	echo '<textarea id="heavy_textarea" name="heavy_theme_header_options[heavy_textarea]" rows="10" cols="50">' . $options['heavy_textarea'] . '</textarea>';
    echo '</div>';
} // end heavy_textarea_element_callback

function heavy_checkbox_element_callback() {

	$options = get_option( 'heavy_theme_header_options' );
	if (isset($options['header_checkbox'])){
	$isset_header_chkbx = $options['header_checkbox'];
	} else { $isset_header_chkbx = 0;}
	$html = '<input type="checkbox" id="header_checkbox" name="heavy_theme_header_options[header_checkbox]" value="1"' . checked( 1, $isset_header_chkbx, false ) . '/>';
	$html .= '<small>'._e('Check this box if you would like to DISABLE header textblock.','heavy').'</small>';
    echo '<div class="heavy_opts">';
	echo $html;
    echo '</div>';
} // end heavy_checkbox_element_callback

/* ------------------------------------------------------------------------ *
 * Setting Callbacks
 * ------------------------------------------------------------------------ */ 
 
 /**
 * Sanitization callback for the social options. Since each of the social options are text inputs,
 * this function loops through the incoming option and strips all tags and slashes from the value
 * before serializing it.
 *	
 * @params	$input	The unsanitized collection of options.
 *
 * @returns			The collection of sanitized values.
 */
function heavy_theme_sanitize_sidebar_options( $input ) {

	// Define the array for the updated options
	$output = array();

	// Loop through each of the options sanitizing the data
	foreach( $input as $key => $val ) {

		if( isset ( $input[$key] ) ) {
			$output[$key] = strip_tags( stripslashes( $input[ $key ] ) );
		} // end if	

	} // end foreach

	// Return the new collection
	return apply_filters( 'heavy_theme_sanitize_sidebar_options', $output, $input );

} // end heavy_theme_sanitize_sidebar_options

function heavy_theme_validate_header_options( $input ) {

	// Create our array for storing the validated options
	$output = array();

	// Loop through each of the incoming options
	foreach( $input as $key => $value ) {

		// Check to see if the current option has a value. If so, process it.
		if( isset( $input[$key] ) ) {

			// Strip all HTML and PHP tags and properly handle quoted strings
			$output[$key] = strip_tags( stripslashes( $input[ $key ] ) );

		} // end if

	} // end foreach

	// Return the array processing any additional functions filtered by this action
	return apply_filters( 'heavy_theme_validate_header_options', $output, $input );

} // end heavy_theme_validate_header_options

?>